SWDEV-269246 - Added missing exports for hipArrayDestroy

Change-Id: I730814720bb618e895efbe2f412e437110bed8bc


[ROCm/hip commit: 6f1a09b47f]
Цей коміт міститься в:
Arya.Rafii
2021-03-01 11:05:31 -05:00
зафіксовано Arya Rafii
джерело d78cd74c98
коміт 20c981abd3
3 змінених файлів з 4 додано та 0 видалено
+2
Переглянути файл
@@ -2300,6 +2300,8 @@ hipError_t hipMallocArray(hipArray** array, const hipChannelFormatDesc* desc, si
size_t height __dparm(0), unsigned int flags __dparm(hipArrayDefault));
hipError_t hipArrayCreate(hipArray** pHandle, const HIP_ARRAY_DESCRIPTOR* pAllocateArray);
hipError_t hipArrayDestroy(hipArray* array);
hipError_t hipArray3DCreate(hipArray** array, const HIP_ARRAY3D_DESCRIPTOR* pAllocateArray);
hipError_t hipMalloc3D(hipPitchedPtr* pitchedDevPtr, hipExtent extent);
+1
Переглянути файл
@@ -84,6 +84,7 @@ hipMalloc3DArray
hipMallocManaged
hipArrayCreate
hipArray3DCreate
hipArrayDestroy
hipMallocArray
hipMemAdvise
hipMemAllocPitch
+1
Переглянути файл
@@ -85,6 +85,7 @@ global:
hipMalloc3DArray;
hipMallocManaged;
hipArrayCreate;
hipArrayDestroy;
hipArray3DCreate;
hipMallocArray;
hipMallocPitch;